# coding=utf-8
#
# This file is part of Hypothesis Legacy Support, which may be found at
# https://github.com/HypothesisWorks/hypothesis-python
#
# Hypothesis Legacy Support is free software: you can redistribute it and/or
# modify it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.

# Hypothesis Legacy Support is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with Hypothesis Legacy Support.
# If not, see <http://www.gnu.org/licenses/>.

from __future__ import division, print_function, absolute_import

import base64
import hashlib
from gzip import GzipFile as GF
from contextlib import contextmanager


@contextmanager
def GzipFile(filename, mode, mtime=None):
    result = GF(filename, mode)
    try:
        yield result
    finally:
        result.close()


def bit_length(n):
    c = 0
    while n:
        c += 1
        n >>= 1
    return c


def sha1(x):
    return hashlib.sha1(str(x))


def b64encode(x):
    return base64.b64encode(str(x))


def b64decode(x):
    return base64.b64decode(str(x))



# coding=utf-8
#
# This file is part of Hypothesis Legacy Support, which may be found at
# https://github.com/HypothesisWorks/hypothesis-python
#
# Hypothesis Legacy Support is free software: you can redistribute it and/or
# modify it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.

# Hypothesis Legacy Support is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with Hypothesis Legacy Support.
# If not, see <http://www.gnu.org/licenses/>.

from hypothesislegacysupport.version import __version__, __version_info__
from hypothesislegacysupport.compat import *  # noqa
import sys

__all__ = [
    '__version__', '__version_info__', 'GzipFile', 'bit_length',
    'sha1', 'b64encode', 'b64decode'
]

if sys.version_info[:2] != (2, 6):
    raise ImportError('hypothesislegacysupport is only for use on Python 2.6')



from __future__ import division, print_function, absolute_import

import os
import sys

from setuptools import setup, find_packages


def local_file(name):
    return os.path.relpath(os.path.join(os.path.dirname(__file__), name))

SOURCE = local_file('src')
README = local_file('README.rst')


# Assignment to placate pyflakes. The actual version is from the exec that
# follows.
__version__ = None


with open(local_file('src/hypothesislegacysupport/version.py')) as o:
    exec(o.read())


PY26_BACKPORTS = ['importlib', 'ordereddict', 'Counter']


install_requires = ['hypothesis==%s' % (__version__,)]

if sys.version_info[:2] == (2, 6):
    install_requires.extend(PY26_BACKPORTS)

setup(
    name='hypothesislegacysupport',
    version=__version__,
    author='David R. MacIver',
    author_email='david@drmaciver.com',
    packages=find_packages(SOURCE),
    package_dir={'': SOURCE},
    url='https://github.com/HypothesisWorks/hypothesis-python',
    license='AGPL',
    install_requires=install_requires,
    extras_require={
        ":python_version == '2.6'": PY26_BACKPORTS,
    }
)
